@@ -25,6 +25,7 @@
 
 #include <gst/gst.h>
 
+#include "gstglelements.h"
 #include "gstglmixerbin.h"
 
 #define GST_CAT_DEFAULT gst_gl_mixer_bin_debug
@@ -139,6 +140,8 @@ G_DEFINE_TYPE_WITH_CODE (GstGLMixerBin, gst_gl_mixer_bin, GST_TYPE_BIN,
     G_ADD_PRIVATE (GstGLMixerBin)
     G_IMPLEMENT_INTERFACE (GST_TYPE_CHILD_PROXY,
         gst_gl_mixer_bin_child_proxy_init));
+GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (glmixerbin, "glmixerbin",
+    GST_RANK_NONE, GST_TYPE_GL_MIXER_BIN, gl_element_init (plugin));
 
 static guint gst_gl_mixer_bin_signals[LAST_SIGNAL] = { 0 };
 
@@ -312,6 +315,10 @@ _create_input_chain (GstGLMixerBin * self, struct input_chain *chain,
   res &= gst_bin_add (GST_BIN (self), chain->in_convert);
   res &= gst_bin_add (GST_BIN (self), chain->in_overlay);
   res &= gst_bin_add (GST_BIN (self), chain->upload);
+  if (!res) {
+    g_warn_if_reached ();
+    return FALSE;
+  }
 
   pad = gst_element_get_static_pad (chain->in_overlay, "src");
   if (gst_pad_link (pad, mixer_pad) != GST_PAD_LINK_OK) {
@@ -319,11 +326,15 @@ _create_input_chain (GstGLMixerBin * self, struct input_chain *chain,
     return FALSE;
   }
   gst_object_unref (pad);
-  res &=
-      gst_element_link_pads (chain->in_convert, "src", chain->in_overlay,
-      "sink");
-  res &=
-      gst_element_link_pads (chain->upload, "src", chain->in_convert, "sink");
+  if (!gst_element_link_pads (chain->in_convert, "src", chain->in_overlay,
+          "sink")) {
+    g_warn_if_reached ();
+    return FALSE;
+  }
+  if (!gst_element_link_pads (chain->upload, "src", chain->in_convert, "sink")) {
+    g_warn_if_reached ();
+    return FALSE;
+  }
 
   pad = gst_element_get_static_pad (chain->upload, "sink");
   if (!pad) {
