@@ -22,6 +22,10 @@
 #include "config.h"
 #endif
 
+#if !defined(MAC_OS_X_VERSION_MAX_ALLOWED) || MAC_OS_X_VERSION_MAX_ALLOWED >= 1014
+# define GL_SILENCE_DEPRECATION
+#endif
+
 #include <Cocoa/Cocoa.h>
 
 #include "gstglcaopengllayer.h"
